@@ -27,7 +27,7 @@ def test_invalid():
     result = runner.invoke(app, ["--network", "capsule"])
     assert result.exit_code != 0
     assert (
-        'Error: Invalid value for "--network": invalid choice: capsule. (choose from simple, conv, lstm)'
+        "Error: Invalid value for '--network': invalid choice: capsule. (choose from simple, conv, lstm)"
         in result.output
     )
 
